
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Carroll, Slacalek and Sommer: International Evidence on Sticky
% Consumption Growth
%
% This MATLAB program is called by run_kalman.m and prints out LaTeX code
% for Table 4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% necessary to input two matrices: tableValues (13x5) matrix of values to
% be printed out in the table and tStats (13x4) matrix of t stats
% corresponding to the first 4 columns of tableVars. 

filePath=[kalmanPath,'\dataNoutput\t1stStage.tex'];
fid=fopen(filePath,'w');

fprintf(fid, '\\begin{table} \n \\caption{ Consumption Dynamics---First-Stage Kalman Filter Estimates \\label{tKalman}} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\begin{eqnarray*} \n \\Delta\\log C_t&=&\\Delta\\log C_t^*+u_t+(\\theta-1)u_{t-1}-\\theta u_{t-2}, \\\\ \n');
fprintf(fid, '\\Delta\\log C_t^*&=&c_0+\\chi\\Delta\\log C_{t-1}^*+v_t+\\lambda_1(\\chi)v_{t-1}+\\lambda_2(\\chi)v_{t-2} \n \\end{eqnarray*} \n');
fprintf(fid, '\\begin{tabular}{@{}ld{4}d{4}d{4}d{4}d{4}@{}}');
fprintf(fid, '\n \\toprule \n \\multicolumn{1}{c}{} &  \\multicolumn{5}{c}{Parameter Estimates} \\\\ \n');
fprintf(fid, '\\cmidrule(r){2-6} \n');
fprintf(fid, 'Country & \\multicolumn{1}{c}{$\\chi$} & \\multicolumn{1}{c}{$\\theta$}');
fprintf(fid, '& \\multicolumn{1}{c}{$\\log \\sigma^2_u$} & \\multicolumn{1}{c}{$\\log \\sigma^2_v$}& ');
fprintf(fid, '\\multicolumn{1}{c}{$\\frac{\\var (\\Delta\\log \\mathbf{C}^*_t)}{\\var (\\Delta\\log \\mathbf{C}_t)}$}\\\\ \n');
fprintf(fid, '\\midrule \n');
fprintf(fid, '\\multicolumn{6}{l}{\\!\\!\\!G7 Countries} \\\\ \n');

% Here are the guts of the table
fprintf(fid, 'Canada${}^\\dagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(1,i)); starr=makeStars(tStats(1,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(1,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'France${}^\\dagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(2,i)); starr=makeStars(tStats(2,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(2,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Germany${}^\\dagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(3,i)); starr=makeStars(tStats(3,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(3,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Italy${}^\\dagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(4,i)); starr=makeStars(tStats(4,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(4,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'United Kingdom${}^\\dagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(5,i)); starr=makeStars(tStats(5,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(5,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'United States${}^\\dagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(6,i)); starr=makeStars(tStats(6,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(6,5)); fprintf(fid,' \\\\ \n \\midrule \n');
fprintf(fid, '\\multicolumn{6}{l}{\\!\\!\\!Other Countries} \\\\ \n');

fprintf(fid, 'Australia${}^\\ddagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(7,i)); starr=makeStars(tStats(7,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(7,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Belgium${}^\\ddagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(8,i)); starr=makeStars(tStats(8,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(8,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Denmark${}^\\ddagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(9,i)); starr=makeStars(tStats(9,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(9,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Finland${}^\\ddagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(10,i)); starr=makeStars(tStats(10,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(10,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Netherlands${}^\\ddagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(11,i)); starr=makeStars(tStats(11,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(11,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Spain${}^\\ddagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(12,i)); starr=makeStars(tStats(12,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(12,5)); fprintf(fid,' \\\\ \n ');

fprintf(fid, 'Sweden${}^\\ddagger$ ');
for i=1:4;
    fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(13,i)); starr=makeStars(tStats(13,i)); fprintf(fid,starr);
end;
fprintf(fid,' & '); fprintf(fid,'%5.2f',tableValues(13,5)); fprintf(fid,' \\\\ \n ');

% Here is the rest
fprintf(fid,['\\bottomrule \n \\end{tabular} \n \\end{center} \n \\showEstTime{Estimated:' datestr(now) ' \\\\ }  \n']);
fprintf(fid,'{\\footnotesize Notes: Consumption variable: $\\dagger$: nondurables, semidurables and services consumption, $\\ddagger$:  total personal consumption expenditure. ');
fprintf(fid,'$\\{{}^*,{}^{**},{}^{***}\\}={}$Statistical significance at $\\{10,5,1\\}$ percent. ');
fprintf(fid,'Samples for the Kalman filter estimation are as follows: Canada Q2:1961--Q4:2006, ');
fprintf(fid,'France Q2:1978--Q4:2006, Germany Q2:1970--Q4:2006, Italy Q2:1981--Q3:2006, ');
fprintf(fid,'United Kingdom Q2:1964--Q3:2006, United States Q2:1960--Q4:2006, Australia Q3:1965--Q4:2003, ');
fprintf(fid,'Belgium, Denmark, Finland and Sweden Q2:1961--Q2:2003, ');
fprintf(fid,'Netherlands Q2:1961--Q2:2004, and Spain Q3:1962--Q2:2003.}');
fprintf(fid,'\\end{table} \n');

fclose(fid);
